#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://ivan.sourceforge.net/
# source           : http://prdownloads.sourceforge.net/ivan/ivan-0.50.tar.gz

# Package name
NAME="ivan"
# Package version
VERSION="0.50"
# Source code URL
SOURCE="http://prdownloads.sourceforge.net/ivan/ivan-$VERSION.tar.gz"
# ./configure options
CONFIGOPTIONS="--prefix=/usr --localstatedir=/usr/share"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL LICENSING NEWS README"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: ivan is a roguelike game
$NAME:
$NAME: Iter Vehemens ad Necem (IVAN) is a graphical roguelike game. It
$NAME: features advanced bodypart and material handling, multi-colored
$NAME: lighting and, above all, deep gameplay.
$NAME: 
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if an icon is present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz
tar xvzf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Iter Vehemens ad Necem
Exec=ivan
Terminal=false
Type=Application
Categories=Game;RolePlaying;
Icon=ivan
EOF

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH"
export CXXFLAGS="-O2 -march=$ARCH"
./configure $CONFIGOPTIONS
# Patch for using gcc>4.0
sed -i -e 's/fearray<type>::fearray<type>/fearray<type>::fearray/' FeLib/Include/fearray.h
 sed -i -e 's/contentscript<character>::contentscript<character>()/contentscript<character>::contentscript()/g' Main/Source/script.cpp
sed -i -e 's/contentscript<item>::contentscript<item>()/contentscript<item>::contentscript()/g' Main/Source/script.cpp
sed -i -e 's/contentscript<olterrain>::contentscript<olterrain>()/contentscript<olterrain>::contentscript()/g' Main/Source/script.cpp
sed -i -e 's/contentmap<type, contenttype>::contentmap<type, contenttype>()/contentmap<type, contenttype>::contentmap()/g' Main/Source/script.cpp
# And patch for using DESTDIR
sed -i -e 's/$(localstatedir)/$(DESTDIR)$(localstatedir)/g' Makefile
sed -i -e 's/$(bindir)/$(DESTDIR)$(bindir)/g' Makefile
sed -i -e 's/$(datadir)/$(DESTDIR)$(datadir)/g' Makefile
# Also patch for saving files in ~/.IvanSave instead of ~/IvanSave
sed -i -e 's,/IvanSave/,/\.IvanSave/,' Main/Source/game.cpp
# Now do make
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Copy icons to the right place
ICONSIZES="128 64 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# But we need to change some permissions
chmod a+w $PKG/usr/share/ivan/ivan-highscore.scores
chmod a+r,u+w $PKG/usr/bin/ivan
chmod a+w,a+x $PKG/usr/share/ivan/Bones

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
